<?php

namespace Drupal\eca_content\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;

/**
 * Set the value of an entity field.
 *
 * @Action(
 *   id = "eca_set_field_value",
 *   label = @Translation("Entity field: set value"),
 *   type = "entity"
 * )
 */
class SetFieldValue extends ConfigurableFieldUpdateActionBase {

  /**
   * {@inheritdoc}
   */
  protected function getFieldsToUpdate() {
    return [$this->configuration['field_name'] => $this->configuration['field_value']];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'field_name' => '',
      'field_value' => '',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['field_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field name'),
      '#default_value' => $this->configuration['field_name'],
    ];
    $form['field_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field value'),
      '#default_value' => $this->configuration['field_value'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['field_name'] = $form_state->getValue('field_name');
    $this->configuration['field_value'] = $form_state->getValue('field_value');
  }

}
