<?php

namespace Drupal\eca_content\Plugin\Action;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\RevisionableInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;
use Drupal\eca\Service\Conditions;

/**
 * Load current entity into token environment.
 *
 * @Action(
 *   id = "eca_token_load_entity",
 *   label = @Translation("Token: load current entity"),
 *   type = "entity"
 * )
 */
class TokenLoadEntity extends ConfigurableActionBase {

  /**
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected EntityInterface $entity;

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL): void {
    if ($entity === NULL) {
      return;
    }
    /** @var \Drupal\Core\Entity\ContentEntityStorageInterface $storage */
    if ($this->configuration['latest_revision'] === Conditions::OPTION_YES &&
      $entity instanceof RevisionableInterface &&
      !$entity->isLatestRevision() &&
      $storage = $this->entityTypeManager->getStorage($entity->getEntityTypeId())) {
      $this->entity = $storage->loadRevision($storage->getLatestRevisionId($entity->id()));
    }
    else {
      $this->entity = $entity;
    }
    $tokenName = empty($this->configuration['token_name']) ? $entity->getEntityTypeId() : $this->configuration['token_name'];
    $this->tokenServices->addTokenData($tokenName, $this->entity);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'token_name' => '',
      'latest_revision' => FALSE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['token_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name of token'),
      '#default_value' => $this->configuration['token_name'],
    ];
    $form['latest_revision'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Load latest revision'),
      '#default_value' => $this->configuration['latest_revision'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['token_name'] = $form_state->getValue('token_name');
    $this->configuration['latest_revision'] = $form_state->getValue('latest_revision');
  }

}
