<?php

namespace Drupal\eca_content\Plugin\Condition;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Plugin\Condition\StringComparisonBase;

/**
 * Plugin implementation of the ECA condition for an entity field value.
 *
 * @Condition(
 *   id = "eca_entity_field_value",
 *   label = "Entity field value",
 *   context_definitions = {
 *     "entity" = @ContextDefinition("entity", label = @Translation("Entity"))
 *   }
 * )
 */
class EntityFieldValue extends StringComparisonBase {

  /**
   * {@inheritdoc}
   */
  protected function getFirstValue(): string {
    $entity = $this->getContextValue('entity');
    if ($entity instanceof FieldableEntityInterface && $entity->hasField($this->configuration['field_name'])) {
      // @todo: How can we better get the field value for all sorts of field types?
      $value = $entity->get($this->configuration['field_name'])->getValue();
      if (is_array($value)) {
        return $value[0]['value'] ?? '';
      }
      return (string) $value;
    }
    return '';
  }

  /**
   * {@inheritdoc}
   */
  protected function getSecondValue(): string {
    return $this->configuration['field_value'];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
        'field_name' => '',
        'field_value' => '',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['field_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field name'),
      '#default_value' => $this->configuration['field_name'],
    ];
    $form['field_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field value'),
      '#default_value' => $this->configuration['field_value'],
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['field_name'] = $form_state->getValue('field_name');
    $this->configuration['field_value'] = $form_state->getValue('field_value');
    parent::submitConfigurationForm($form, $form_state);
  }

}
