<?php

namespace Drupal\eca_content\Plugin\Condition;

use Drupal\Core\Entity\FieldableEntityInterface;

/**
 * Plugin implementation of the ECA condition for an entity original field value.
 *
 * @Condition(
 *   id = "eca_entity_original_field_value",
 *   label = "Entity original field value",
 *   context_definitions = {
 *     "entity" = @ContextDefinition("entity", label = @Translation("Entity"))
 *   }
 * )
 */
class EntityOriginalFieldValue extends EntityFieldValue {

  /**
   * {@inheritdoc}
   */
  protected function getFirstValue(): string {
    $entity = $this->getContextValue('entity');
    if ($entity instanceof FieldableEntityInterface && isset($entity->original) && $entity->hasField($this->configuration['field_name'])) {
      return $entity->original->get($this->configuration['field_name'])->getValue();
    }
    return '';
  }

}
