<?php

namespace Drupal\eca_content\Plugin\ECA\Event;

use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\eca_content\EntityTypeTrait;
use Drupal\eca_content\Event\ContentEntityBundleCreate;
use Drupal\eca_content\Event\ContentEntityBundleDelete;
use Drupal\eca_content\Event\ContentEntityCreate;
use Drupal\eca_content\Event\ContentEntityDelete;
use Drupal\eca_content\Event\ContentEntityEvents;
use Drupal\eca_content\Event\ContentEntityFieldValuesInit;
use Drupal\eca_content\Event\ContentEntityInsert;
use Drupal\eca_content\Event\ContentEntityLoad;
use Drupal\eca_content\Event\ContentEntityPreDelete;
use Drupal\eca_content\Event\ContentEntityPreLoad;
use Drupal\eca_content\Event\ContentEntityPrepareForm;
use Drupal\eca_content\Event\ContentEntityPrepareView;
use Drupal\eca_content\Event\ContentEntityPreSave;
use Drupal\eca_content\Event\ContentEntityRevisionCreate;
use Drupal\eca_content\Event\ContentEntityRevisionDelete;
use Drupal\eca_content\Event\ContentEntityStorageLoad;
use Drupal\eca_content\Event\ContentEntityTranslationCreate;
use Drupal\eca_content\Event\ContentEntityTranslationDelete;
use Drupal\eca_content\Event\ContentEntityTranslationInsert;
use Drupal\eca_content\Event\ContentEntityUpdate;
use Drupal\eca_content\Event\ContentEntityView;

/**
 * Plugin implementation of the ECA Events for content entities.
 *
 * @EcaEvent(
 *   id = "content_entity",
 *   deriver = "Drupal\eca_content\Plugin\ECA\Event\ContentEntityEventDeriver"
 * )
 */
class ContentEntityEvent extends EventBase {

  use EntityTypeTrait;

  /**
   * @return array[]
   */
  public static function actions(): array {
    return [
      'bundlecreate' => [
        'label' => 'Create content entity bundle',
        'drupal_id' => ContentEntityEvents::BUNDLECREATE,
        'drupal_event_class' => ContentEntityBundleCreate::class,
      ],
      'bundledelete' => [
        'label' => 'Delete content entity bundle',
        'drupal_id' => ContentEntityEvents::BUNDLEDELETE,
        'drupal_event_class' => ContentEntityBundleDelete::class,
      ],
      'create' => [
        'label' => 'Create content entity',
        'drupal_id' => ContentEntityEvents::CREATE,
        'drupal_event_class' => ContentEntityCreate::class,
      ],
      'revisioncreate' => [
        'label' => 'Create content entity revision',
        'drupal_id' => ContentEntityEvents::REVISIONCREATE,
        'drupal_event_class' => ContentEntityRevisionCreate::class,
      ],
      'preload' => [
        'label' => 'Preload content entity',
        'drupal_id' => ContentEntityEvents::PRELOAD,
        'drupal_event_class' => ContentEntityPreLoad::class,
      ],
      'load' => [
        'label' => 'Load content entity',
        'drupal_id' => ContentEntityEvents::LOAD,
        'drupal_event_class' => ContentEntityLoad::class,
      ],
      'storageload' => [
        'label' => 'Load content entity from storage',
        'drupal_id' => ContentEntityEvents::STORAGELOAD,
        'drupal_event_class' => ContentEntityStorageLoad::class,
      ],
      'presave' => [
        'label' => 'Presave content entity',
        'drupal_id' => ContentEntityEvents::PRESAVE,
        'drupal_event_class' => ContentEntityPreSave::class,
      ],
      'insert' => [
        'label' => 'Insert content entity',
        'drupal_id' => ContentEntityEvents::INSERT,
        'drupal_event_class' => ContentEntityInsert::class,
      ],
      'update' => [
        'label' => 'Update content entity',
        'drupal_id' => ContentEntityEvents::UPDATE,
        'drupal_event_class' => ContentEntityUpdate::class,
      ],
      'translationcreate' => [
        'label' => 'Create content entity translation',
        'drupal_id' => ContentEntityEvents::TRANSLATIONCREATE,
        'drupal_event_class' => ContentEntityTranslationCreate::class,
      ],
      'translationinsert' => [
        'label' => 'Insert content entity translation',
        'drupal_id' => ContentEntityEvents::TRANSLATIONINSERT,
        'drupal_event_class' => ContentEntityTranslationInsert::class,
      ],
      'translationdelete' => [
        'label' => 'Delete content entity translation',
        'drupal_id' => ContentEntityEvents::TRANSLATIONDELETE,
        'drupal_event_class' => ContentEntityTranslationDelete::class,
      ],
      'predelete' => [
        'label' => 'Predelete content entity',
        'drupal_id' => ContentEntityEvents::PREDELETE,
        'drupal_event_class' => ContentEntityPreDelete::class,
      ],
      'delete' => [
        'label' => 'Delete content entity',
        'drupal_id' => ContentEntityEvents::DELETE,
        'drupal_event_class' => ContentEntityDelete::class,
      ],
      'revisiondelete' => [
        'label' => 'Delete content entity revision',
        'drupal_id' => ContentEntityEvents::REVISIONDELETE,
        'drupal_event_class' => ContentEntityRevisionDelete::class,
      ],
      'view' => [
        'label' => 'View content entity',
        'drupal_id' => ContentEntityEvents::VIEW,
        'drupal_event_class' => ContentEntityView::class,
      ],
      'prepareview' => [
        'label' => 'Prepare content entity view',
        'drupal_id' => ContentEntityEvents::PREPAREVIEW,
        'drupal_event_class' => ContentEntityPrepareView::class,
      ],
      'prepareform' => [
        'label' => 'Prepare content entity form',
        'drupal_id' => ContentEntityEvents::PREPAREFORM,
        'drupal_event_class' => ContentEntityPrepareForm::class,
      ],
      'fieldvaluesinit' => [
        'label' => 'Init content entity field values',
        'drupal_id' => ContentEntityEvents::FIELDVALUESINIT,
        'drupal_event_class' => ContentEntityFieldValuesInit::class,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $fields = parent::fields();
    $fields[] = $this->bundleField(TRUE);
    return $fields;
  }

}
