<?php

namespace Drupal\eca_form\Plugin\ECA\Event;

use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\eca_form\Event\FormBuild;
use Drupal\eca_form\Event\FormSubmit;
use Drupal\eca_form\Event\FormValidate;

/**
 * Plugin implementation of the ECA Events for the form API.
 *
 * @EcaEvent(
 *   id = "form",
 *   deriver = "Drupal\eca_form\Plugin\ECA\Event\FormEventDeriver"
 * )
 */
class FormEvent extends EventBase {

  public const FORMBUILD = 'eca.content_entity.formbuild';

  public const FORMVALIDATE = 'eca.content_entity.formvalidate';

  public const FORMSUBMIT = 'eca.content_entity.formsubmit';

  /**
   * @return array[]
   */
  public static function actions(): array {
    $actions = [];
    $actions['form_build'] = [
      'label' => 'Build form',
      'drupal_id' => self::FORMBUILD,
      'drupal_event_class' => FormBuild::class,
    ];
    $actions['form_validate'] = [
      'label' => 'Validate form',
      'drupal_id' => self::FORMVALIDATE,
      'drupal_event_class' => FormValidate::class,
    ];
    $actions['form_submit'] = [
      'label' => 'Submit form',
      'drupal_id' => self::FORMSUBMIT,
      'drupal_event_class' => FormSubmit::class,
    ];
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $fields = [];
    $fields[] = [
      'name' => 'form_id',
      'label' => 'Form ID',
      'type' => 'String',
    ];
    return $fields;
  }

}
