<?php

namespace Drupal\eca_user\Plugin\ECA\Event;

use Drupal\Core\Session\AccountEvents;
use Drupal\Core\Session\AccountSetEvent;
use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\eca_user\Event\UserCancel;
use Drupal\eca_user\Event\UserEvents;
use Drupal\eca_user\Event\UserLogin;
use Drupal\eca_user\Event\UserLogout;
use Drupal\user\Event\UserEvents as CoreUserEvents;
use Drupal\user\Event\UserFloodEvent;

/**
 * Plugin implementation of the ECA Events for users.
 *
 * @EcaEvent(
 *   id = "user",
 *   deriver = "Drupal\eca_user\Plugin\ECA\Event\UserEventDeriver"
 * )
 */
class UserEvent extends EventBase {

  /**
   * @return array[]
   */
  public static function actions(): array {
    return [
      'login' => [
        'label' => 'Login of a user',
        'drupal_id' => UserEvents::LOGIN,
        'drupal_event_class' => UserLogin::class,
      ],
      'logout' => [
        'label' => 'Logout of a user',
        'drupal_id' => UserEvents::LOGOUT,
        'drupal_event_class' => UserLogout::class,
      ],
      'cancel' => [
        'label' => 'Cancelling a user',
        'drupal_id' => UserEvents::CANCEL,
        'drupal_event_class' => UserCancel::class,
      ],
      'floodblockip' => [
        'label' => 'Flood blocked IP',
        'drupal_id' => CoreUserEvents::FLOOD_BLOCKED_IP,
        'drupal_event_class' => UserCancel::class,
      ],
      'floodblockuser' => [
        'label' => 'Flood blocked user',
        'drupal_id' => CoreUserEvents::FLOOD_BLOCKED_USER,
        'drupal_event_class' => UserFloodEvent::class,
      ],
      'set_user' => [
        'label' => 'Set current user',
        'drupal_id' => AccountEvents::SET_USER,
        'drupal_event_class' => AccountSetEvent::class,
      ],
    ];
  }

}
