<?php

namespace Drupal\eca\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\eca\Service\Modellers;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class Eca.
 *
 * @package Drupal\eca\Controller
 */
class EcaController extends ControllerBase {

  /**
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $request;

  /**
   * @var \Drupal\eca\Service\Modellers
   */
  protected Modellers $modellerServices;

  /**
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected EntityStorageInterface $storage;

  /**
   * ECA controller constructor.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param \Drupal\eca\Service\Modellers $modeller_services
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   */
  public function __construct(Request $request, Modellers $modeller_services, EntityTypeManagerInterface $entity_type_manager) {
    $this->request = $request;
    $this->modellerServices = $modeller_services;
    $this->storage = $entity_type_manager->getStorage('eca');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): EcaController {
    return new static(
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('eca.service.modeller'),
      $container->get('entity_type.manager')
    );
  }

  public function edit(string $eca): array {
    /** @var \Drupal\eca\Entity\Eca $config */
    if (($config = $this->storage->load($eca)) && $config->isEditable() && $modeller = $config->getModeller()) {
      $build = $modeller->edit();
      $build['#title'] = $this->t('ECA Model: %label', ['%label' => $config->label()]);
      return $build;
    }
    return [];
  }

  public function save(string $modeller_id): AjaxResponse {
    if ($modeller = $this->modellerServices->getModeller($modeller_id)) {
      $modeller->save($this->request->getContent());
    }
    return new AjaxResponse();
  }

}
