<?php

namespace Drupal\eca\Entity\Objects;

use Drupal\Component\EventDispatcher\Event;
use Drupal\eca\Plugin\Action\ActionInterface;
use Drupal\eca\Entity\Eca;
use Drupal\Core\Action\ActionInterface as CoreActionInterface;

class EcaAction extends EcaObject {

  /**
   * @var \Drupal\Core\Action\ActionInterface
   */
  protected CoreActionInterface $plugin;

  /**
   * Event constructor.
   *
   * @param \Drupal\eca\Entity\Eca $eca
   * @param string $id
   * @param string $label
   * @param \Drupal\eca\Entity\Objects\EcaEvent $event
   * @param \Drupal\Core\Action\ActionInterface $plugin
   */
  public function __construct(Eca $eca, string $id, string $label, EcaEvent $event, CoreActionInterface $plugin) {
    parent::__construct($eca, $id, $label, $event);
    $this->plugin = $plugin;
  }

  /**
   * {@inheritdoc}
   */
  public function execute(EcaObject $predecessor, Event $event, array $context): bool {
    if ($this->plugin instanceof ActionInterface) {
      $this->plugin->setEvent($event);
    }
    $object = $this->getObject($this->plugin);
    try {
      if (!$this->plugin->access($object)) {
        $this->logger->warning('Access denied to %actionlabel (%actionid) from ECA %ecalabel (%ecaid) for event %event.', $context);
        return FALSE;
      }
      $this->plugin->execute($object);
      return TRUE;
    }
    catch (\Exception $ex) {
      $context['%exmsg'] = $ex->getMessage();
      $context['%extrace'] = $ex->getTraceAsString();
      $this->logger()->error('Failed execution of %actionlabel (%actionid) from ECA %ecalabel (%ecaid) for event %event: %exmsg.\n\n%extrace', $context);
    }
    return FALSE;
  }

}
