<?php

namespace Drupal\eca\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\eca\Processor;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Base ECA event subscriber.
 */
abstract class EcaBase implements EventSubscriberInterface {

  /**
   * @var \Drupal\eca\Processor
   */
  protected Processor $processor;

  /**
   * ContentEntity constructor.
   *
   * @param \Drupal\eca\Processor $processor
   */
  public function __construct(Processor $processor) {
    $this->processor = $processor;
  }

  /**
   * @param \Drupal\Component\EventDispatcher\Event $event
   */
  public function onEvent(Event $event): void {
    try {
      $this->processor->execute($event);
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      // This is thrown during installation of eca and we can ignore this.
    }
  }

}
