<?php

namespace Drupal\eca\Plugin\ECA\Modeller;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\eca\Entity\Eca;

/**
 * Interface for ECA modeller plugins.
 */
interface ModellerInterface extends PluginInspectionInterface {

  /**
   * Add the ECA config entity to the modeller.
   *
   * This allows the modeller to call back to the currently operating ECA
   * config which holds additional information and functionality.
   *
   * @param \Drupal\eca\Entity\Eca $eca
   *   The ECA config entity for the modeller to work on.
   *
   * @return \Drupal\eca\Plugin\ECA\Modeller\ModellerInterface
   *   The modeller instance itself.
   */
  public function setConfigEntity(Eca $eca): ModellerInterface;

  /**
   * @param string $model_data
   * @param string|null $filename
   *
   * @return \Drupal\eca\Plugin\ECA\Modeller\ModellerInterface
   */
  public function save(string $model_data, string $filename = NULL): ModellerInterface;

  /**
   * @return string
   */
  public function getFilename(): string;

  /**
   * @return string
   */
  public function getModeldata(): string;

  /**
   * @return bool
   */
  public function isEditable(): bool;

  /**
   * @return array
   */
  public function edit(): array;

  /**
   * @return string
   */
  public function getId(): string;

  /**
   * @return string
   */
  public function getLabel(): string;

  /**
   * @return bool
   */
  public function getStatus(): bool;

  /**
   * @return string
   */
  public function getVersion(): string;

  /**
   * @param \Drupal\eca\Entity\Eca $eca
   *
   * @return \Drupal\eca\Plugin\ECA\Modeller\ModellerInterface
   */
  public function readComponents(Eca $eca): ModellerInterface;

  /**
   * @return \Drupal\eca\Plugin\ECA\Modeller\ModellerInterface
   */
  public function export(): ModellerInterface;

}
